@@ -12,11 +12,8 @@
 #ifndef __KATZE_THROBBER_H__
 #define __KATZE_THROBBER_H__
 
-#include <gdk/gdk.h>
 #include <gtk/gtk.h>
 
-#include "katze-utils.h"
-
 G_BEGIN_DECLS
 
 #define KATZE_TYPE_THROBBER \
@@ -36,13 +33,6 @@ typedef struct _KatzeThrobber                KatzeThrobber;
 typedef struct _KatzeThrobberPrivate         KatzeThrobberPrivate;
 typedef struct _KatzeThrobberClass           KatzeThrobberClass;
 
-struct _KatzeThrobber
-{
-    GtkMisc parent_instance;
-
-    KatzeThrobberPrivate* priv;
-};
-
 struct _KatzeThrobberClass
 {
     GtkMiscClass parent_class;
